@@ -13,7 +13,7 @@ def _refactor_helper(refactor_func, input_src, change_spec) -> str:
         ntf.write(input_src.encode('utf-8'))
         ntf.close()
         q = Query(ntf.name)
-        refactor_func(q, change_spec).execute(interactive=False, write=True, silent=True)
+        refactor_func(q, change_spec).execute(write=True, silent=True, need_confirm=False, print_hint=False)
         with open(ntf.name, 'r') as f:
             output_src = f.read()
         return output_src
